@@ -9,7 +9,7 @@ from adrest.auth import AuthenticatorMixin, AnonimousAuthenticator
 from adrest.emitters import EmitterMixin, XMLTemplateEmitter, JSONTemplateEmitter, JSONEmitter
 from adrest.handlers import HandlerMixin
 from adrest.parsers import ParserMixin, XMLParser, JSONParser, FormParser
-from adrest.settings import DEBUG
+from adrest.settings import DEBUG, AUTHENTICATE_OPTIONS_REQUEST
 from adrest.signals import api_request_started, api_request_finished
 from adrest.throttle import ThrottleMixin
 from adrest.utils import HttpError, Response, as_tuple
@@ -22,7 +22,7 @@ class ResourceView(HandlerMixin, ThrottleMixin, EmitterMixin, ParserMixin, Authe
     api = None
 
     log = True
-    
+
     # Since we handle cross-origin XML HTTP requests, let OPTIONS be another default allowed method.
     allowed_methods = ('GET', 'OPTIONS')
 
@@ -51,7 +51,11 @@ class ResourceView(HandlerMixin, ThrottleMixin, EmitterMixin, ParserMixin, Authe
             self.check_method_allowed(method)
 
             # Authentificate
-            self.identifier = self.authenticate()
+            # We do not restrict access for OPTIONS request.
+            if method == 'OPTIONS' and not AUTHENTICATE_OPTIONS_REQUEST:
+                self.identifier = 'anonymous'
+            else:
+                self.identifier = self.authenticate()
 
             # Throttle check
             self.throttle_check()
@@ -83,7 +87,8 @@ class ResourceView(HandlerMixin, ThrottleMixin, EmitterMixin, ParserMixin, Authe
         response.headers['Vary'] = 'Authenticate, Accept'
 
         # Serialize response
-        response = self.emit(request, response)
+        emitter = JSONEmitter if method == 'OPTIONS' else None
+        response = self.emit(request, response, emitter=emitter)
 
         # Send finished signal
         api_request_finished.send(self, request=self.request, response=response)
@@ -215,7 +220,7 @@ class ResourceView(HandlerMixin, ThrottleMixin, EmitterMixin, ParserMixin, Authe
 
 
 class TopResource(ResourceView):
-    """ TODO: Not implementated.
+    """ TODO: Not implemented.
     """
 
     log = False
